pub struct RiRedisQueue { /* private fields */ }Expand description
Redis queue implementation for the Ri queue system.
This struct provides a Redis implementation of the RiQueue trait, allowing sending and receiving messages using Redis lists as the underlying message broker.
Implementations